# frozen_string_literal: true

require 'import'
require 'cht-lib-fabric/tasks/actionable'
require 'flow_down/actions'

module FlowDown
  module Actions
    # Cleanup flow down items related to an organization that has been deleted.
    #
    # The input is an CRN  object that identifies the organization that has been deleted.
    class OrganizationDeleted
      include ::Platform::Tasks::Actionable
      include Import['alert', 'logger', 'flow_down.data.data_store']

      def call(crn: crn)

        logger.info { "Cleaning up flow down items for org #{crn}" }

        # Parse out inputs for flow down API call
        customer_id = crn.customer
        organization_id = crn.details
        # Won't have a user here as its triggered by a kafka event
        user_id = "";

        # Input is nil. This will make sure we fetch all types of flow down items related
        # to customer_id and organization_id
        flow_down_items_to_delete = data_store.get_flow_down_items(nil, customer_id, organization_id)

        items_to_delete = []
        for item in flow_down_items_to_delete
          items_to_delete << ::FlowDown::Models::EnableFlowDown.new(id: item.id,
                                                                    enable: false)
        end

        data_store.enable_flow_down(items_to_delete, customer_id, organization_id, user_id)

      rescue StandardError => ex
        logger.error("OrganizationDeleted: #{ex.class}: #{ex.message}")
        alert.exception(ex, "OrganizationDeleted")
        raise ex
      end
    end
  end
end
