# frozen_string_literal: true

require 'cht-lib-fabric/graphql/client'
require 'import'
require 'flow_down/traceable'

module FlowDown
  module Clients
    class OrgManagement < ::Platform::GraphQL::Client
      include Import['alert','logger']
      extend Traceable
      # The query file and json file are generated by a Rake task
      schema(File.expand_path('org_management.json', __dir__))
      queries(File.expand_path('org_management.graphql', __dir__))

      def get_organization_ancestors(context = {})
        params = {}
        data = query_with_retry(Queries::OrganizationAncestors, context, ::FlowDown::Retry::RATE_RETRY_LIMIT, params)
        data.to_h.with_indifferent_access
      rescue => ex
        logger.error("OrgManagement Client: get_organization_ancestors: #{ex.class}: #{ex.message}")
        alert.exception(ex, "OrgManagement Client: get_organization_ancestors")
        nil
      end

      trace_method :get_organization_ancestors
    end
  end
end
