# frozen_string_literal: true

require 'import'

module FlowDown
  module Data
    class DataStore
      include Import['logger',
                     'alert',
                     'flow_down.data.persistent_store']

      # Top layer store works with caching
      def get_flow_down_items(input, customer_id, organization_id)
        logger.info "Fetching flow down items from data store for Customer [#{customer_id}] in Organization [#{organization_id}]"
        persistent_store.get_flow_down_items(input, customer_id, organization_id)
      rescue StandardError => ex
        logger.error("DataStore: get_flow_down_items: #{ex.class}: #{ex.message}")
        alert.exception(ex, "DataStore: get_flow_down_item")
        raise ex
      end

      def enable_flow_down(input, customer_id, organization_id, user_id)
        logger.info "Enabling/Disabling flow down items from data store for Customer [#{customer_id}] in Organization [#{organization_id}]"
        persistent_store.enable_flow_down(input, customer_id, organization_id, user_id)
      rescue StandardError => ex
        logger.error("DataStore: enable_flow_down: #{ex.class}: #{ex.message}")
        alert.exception(ex, "DataStore: enable_flow_down")
        raise ex
      end

    end
  end
end
