# frozen_string_literal: true

require 'import'

module FlowDown
  module Data
    class ExpressionHelper
      include Import['logger',
                     'dynamodb.flow_down_table']

      #
      # For building our base DynamoDB query
      #
      def build_base_query(input, customer_id, organization_id)
        base_query =
          {
            table_name: flow_down_table.name,
            index_name: 'flowdown_items',
            key_condition_expression: 'customer_id = :customer_id and organization_id = :organization_id',
            expression_attribute_values: build_query_expression(input, customer_id, organization_id)
          }
        base_query[:filter_expression] = build_filter_expression(input) unless no_input?(input: input)
        logger.debug "Base Query #{base_query}"
        base_query
      end

      #
      # For adding query expression items
      #
      def build_query_expression(input, customer_id, organization_id)
        base_expression = {
          ':customer_id' => customer_id.to_s,
          ':organization_id' => organization_id.to_s
        }
        # Have to include filter fields in expression attribute value as well
        if input
          base_expression[":content_type"] = input[:type] unless input[:type].nil?
          base_expression[":id"] = input[:id] unless input[:id].nil?
        end
        logger.debug "Base Expression #{base_expression}"
        base_expression
      end

      #
      # For adding filter expression items
      #
      def build_filter_expression(input)
        base_expression = []
        if input
          base_expression << "content_type = :content_type" unless input[:type].nil?
          base_expression << "id = :id" unless input[:id].nil?
        end
        logger.debug "Base Filter Expression #{base_expression}"
        # TODO: We should expose this in the API at some point
        base_expression.join(' and ')
      end

      #
      # Returns a boolean whether input has been supplied
      #
      def no_input?(input:)
        return input.nil? || input.keys.empty?
      end
    end
  end
end
