# frozen_string_literal: true

require 'graphql'
require 'cht-lib-fabric/crn'

module FlowDown
  module GraphQL
    module Types
      class FlowDownItem < ::Platform::GraphQL::Types::BaseObject
        description "Represents an item enabled for flowdown in an organization"
        field :id, ID, "Represents an ID of a content item to enable flow down for", null: false
        field :enabled, Boolean, "Represents a boolean indicating wether flow down was successfully enabled or disabled", null: false
        field :organization_id, ID, "Represents the organization that shared this content", null: false
        field :customer_id, ID, "Represents the customer that shared this content", null: false
        field :content_type, ID, "Represents the type of content", null: false
        field :content_id, String, "Represents the unique identifier for this content", null: false
        field :enabled_by_id, String, "Represents the identity of the user that enabled or disabled flowdown", null: true
        field :enabled_at, ::GraphQL::Types::ISO8601DateTime, "Represents the datetime that flowdown was enabled or disabled", null: true

        def enabled_by_id
          obj_h = object.to_h.with_indifferent_access
          return nil if obj_h['enabled_by_id'].nil?
          ::Platform::CRNs::User.new(
            user: obj_h['enabled_by_id'].to_i,
            customer: obj_h['customer_id'].to_i
          )
        end

        def enabled_at
          obj_h = object.to_h.with_indifferent_access
          return nil if obj_h['enabled_at'].nil?
          DateTime.iso8601(obj_h['enabled_at'])
        end
      end
    end
  end
end
