# frozen_string_literal: true

require 'graphql'

module FlowDown
  module GraphQL
    module Types
      module Mutations
        class EnableFlowDown < ::GraphQL::Schema::Mutation
          include Import['logger',
                         'flow_down.data.data_store']

          description "Enables or Disables Flow Down for an item or items"

          argument :input, [EnableFlowDownInput], "Represents a set of items to enable flow down for", required: true

          field :items, [FlowDownItem], "Represents a set of items that were enabled for flow down", null: false

          def resolve(input:)
            logger.info "Enabling or disabling flow down"

            if context[:request].current_organization.nil?
              raise ::GraphQL::ExecutionError, "An organization is required"
            end
            if context[:request].current_customer.nil?
              raise ::GraphQL::ExecutionError, "An customer is required"
            end
            # Enable or Disable Flow Down Through DataStore
            begin
              items = data_store.enable_flow_down(input, 
                                          context[:request].current_customer, 
                                          context[:request].current_organization,
                                          context[:request].current_user)
              # Apply extra formatting here
              { items: items }
            rescue ::FlowDown::Exceptions::NotFound
              raise ::GraphQL::ExecutionError, "EnableFlowDown: flow down item not found"
            rescue ::FlowDown::Exceptions::AlreadyExists
              raise ::GraphQL::ExecutionError, "EnableFlowDown: flow down item already exists"
            end
          end
        end
      end
    end
  end
end
