require 'graphql'
require 'import'
require 'cht-lib-fabric/crn'

module FlowDown
  module GraphQL
    module Types
      class Query < ::Platform::GraphQL::Types::BaseObject
        include Import['logger',
                       'flow_down.data.data_store',
                       'flow_down.helpers.organization_helper']

        description "Query root"


        field :flow_down_items, [FlowDownItem], null: false do
            description <<~DESC
            Returns a list of flow down items shared with an organization. If no
            input is supplied, all flow down content shared from ancestor organizations
            is returned.
            DESC
            argument :input, FlowDownItemInput, "Represents the type of flow down items", required: false
        end


        field :flow_down_items_by_org, [FlowDownItem], null: false do
          description <<~DESC
          Returns a list of flow down items for the current organization. If no
          input is supplied, all flow down content shared by the current organization
          is returned.
          DESC
          argument :input, FlowDownItemInput, "Represents the type of flow down items", required: false
        end

        def flow_down_items(input: nil)
          logger.info "Fetching flow down items"

          if context[:request].current_organization.nil?
            raise ::GraphQL::ExecutionError, "An organization is required"
          end
          if context[:request].current_customer.nil?
            raise ::GraphQL::ExecutionError, "An customer is required"
          end

          # Fetch from ancestor orgs
          flow_down_items = []
          orgs = organization_helper.get_organization_ancestors(context)
          # TODO: Optimize this with an array of orgs and an IN query if possible
          orgs.each do |org|
            item_crn = ::Platform::CRN.from_s(org[:id])
            # Fetch items from our data store
            items = data_store.get_flow_down_items(input,
                                            context[:request].current_customer,
                                            item_crn.details.to_s)
            flow_down_items.concat(items) unless items.empty?
          end unless orgs.nil?
          flow_down_items

        end

        def flow_down_items_by_org(input: nil)
          logger.info "Fetching flow down items"

          if context[:request].current_organization.nil?
            raise ::GraphQL::ExecutionError, "An organization is required"
          end
          if context[:request].current_customer.nil?
            raise ::GraphQL::ExecutionError, "An customer is required"
          end

          # Fetch items from current org
          data_store.get_flow_down_items(input,
                                         context[:request].current_customer,
                                         context[:request].current_organization)

        end

      end
    end
  end
end
