# frozen_string_literal: true

require 'import'
require 'flow_down/actions/organization_deleted'

module FlowDown
  module Helpers
    class OrganizationHelper
      include Import['alert',
                     'logger',
                     'clients.org_management']
      #
      # Returns an array of organizations that are ancestors of the current
      # organization
      #
      def get_organization_ancestors(context)
        ancestor_orgs = org_management.get_organization_ancestors(context)
        if ancestor_orgs.nil?
          logger.debug "No Ancestor Orgs Found for current org [#{context[:request].current_organization}]"
          []
        else
          logger.debug "Ancestor Orgs Found [#{ancestor_orgs[:organizationAncestors]}] for current org [#{context[:request].current_organization}]"
          ancestor_orgs[:organizationAncestors]
        end
      end

      def cleanup_org(params)
        logger.debug{"Processing org change message. params: #{params.to_h}"}
        crn = ::Platform::CRNs::Organization.from_s(params['crn'])
        customer_id = crn.customer
        action = params['action'].downcase
        case action
          when 'delete'
            logger.info { "org #{crn} has been deleted. Cleaning up flow down records" }
            FlowDown::Actions::OrganizationDeleted.call(crn: crn)
          else
            # Warn and move on. We don't want to hold up the line for
            # legitimate messages behind this one.
            alert.warn(
                "Unexpected org change action: #{action.inspect}",
                params: params,
                customer_id: customer_id
            )
          end
        rescue => ex
          params_to_h = params.to_h
          alert.exception(
              ex,
              params: params_to_h,
              customer_id: (defined?(crn) && !crn.nil?) ? customer_id : nil
          )
          raise
      end
    end
  end
end
